import numpy as _np

boltzmann = 1.38064852e-23  # m2 kg s-2 K-1
clight = 299792458  # m / s
h = 6.62607004e-34  # m2 kg / s
mu_B = 9.27400999457e-24
g_e = 2.00231930436153
h_bar = 1.054571817e-34
pi = _np.pi
